@@ -40,9 +40,9 @@
 #include <klibloader.h>
 #include <tdelocale.h>
 #include <kprocess.h>
-#if KDE_IS_VERSION(3,4,0)
+
 #include <twin.h>
-#endif
+
 #include <stdio.h>
 #include <X11/Xlib.h>
 #include <X11/extensions/shape.h>
@@ -76,10 +76,10 @@ int main(int argc, char **argv)
    app.setMainWidget(mainBAB);
    Corner leftCorner(Corner::left);
    Corner rightCorner(Corner::right);
-#if KDE_IS_VERSION(3,4,0)
+
    KWin::setShadowSize(leftCorner.winId(), 0);
    KWin::setShadowSize(rightCorner.winId(), 0);
-#endif
+
    if (!mainBAB->cornerCheck->isChecked())
    {
       leftCorner.hide();
