@@ -109,7 +109,7 @@ class BaghiraClient;
 class ResizeHandle : public TQWidget
 {
 friend class BaghiraClient;
-    Q_OBJECT
+    TQ_OBJECT
 public:
     ResizeHandle(BaghiraClient *parent);
 protected:
@@ -129,7 +129,7 @@ class DeMaximizer : public TQWidget
 {
 friend class BaghiraClient;
 friend class BaghiraFactory;
-    Q_OBJECT
+    TQ_OBJECT
 public:
     DeMaximizer();
     void setClient(BaghiraClient *);
@@ -323,7 +323,7 @@ inline int BaghiraFactory::borderSize(int current)
 
 class BaghiraButton : public TQButton
 {
-   Q_OBJECT
+   TQ_OBJECT
 public:
     BaghiraButton(BaghiraClient *parent=0, const char *name=0, const TQString &tip=NULL, bool small=false, ButtonType type=MinButton, int style=0);
     ~BaghiraButton();
@@ -373,7 +373,7 @@ class BaghiraClient : public KDecoration
 {
 friend class BaghiraButton;
 friend class ResizeHandle;
-    Q_OBJECT
+    TQ_OBJECT
 public:
    BaghiraClient(KDecorationBridge *b, KDecorationFactory *f);
    virtual ~BaghiraClient();
