@@ -95,7 +95,7 @@ class ButtonTile
 
 class OptionHandler : public TQObject
 {
-   Q_OBJECT
+   TQ_OBJECT
 public:
    OptionHandler( TQObject *parent );
    void reloadSettings();
@@ -462,7 +462,7 @@ protected:
 
 class EventKiller : public TQObject
 {
-   Q_OBJECT
+   TQ_OBJECT
 public:
    bool eventFilter( TQObject *, TQEvent *)
    {
@@ -472,7 +472,7 @@ public:
 
 class BMShower : public TQObject
 {
-   Q_OBJECT
+   TQ_OBJECT
 public:
    BMShower(TQObject *parent);
    bool eventFilter( TQObject *object, TQEvent *event );
@@ -493,7 +493,7 @@ public:
 
 class LiquidStyle : public TDEStyle
 {
-   Q_OBJECT
+   TQ_OBJECT
 public:
    friend class OptionHandler;
    LiquidStyle();
