@@ -13,7 +13,7 @@ bool LiquidStyle::objectEventHandler( const TQStyleControlElementData &ceData,
         return true;
    }
 
-   if (!ceData.widgetObjectTypes.contains(TQOBJECT_OBJECT_NAME_STRING)) {
+   if (!ceData.widgetObjectTypes.contains("TQObject")) {
         return false;
    }
    TQObject* obj = reinterpret_cast<TQObject*>(source);
