@@ -206,7 +206,7 @@ void LiquidStyle::polish( TQPalette &pal )
 
 void LiquidStyle::applicationUnPolish( const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, void *ptr )
 {
-	if (ceData.widgetObjectTypes.contains(TQAPPLICATION_OBJECT_NAME_STRING)) {
+	if (ceData.widgetObjectTypes.contains("TQApplication")) {
 		TQApplication *app = reinterpret_cast<TQApplication*>(ptr);
 		popupBack.resize(0,0);
 		TQPalette pal( app->palette() );
@@ -236,7 +236,7 @@ void LiquidStyle::polish( const TQStyleControlElementData &ceData, ControlElemen
 //     if (w->sizePolicy().horData() == TQSizePolicy::Minimum || w->sizePolicy().horData() == TQSizePolicy::MinimumExpanding)
 // 	tqWarning("%s, \"%s\"",w->className(), w->name());
 //	installObjectEventHandler(ceData, elementFlags, ptr, this);
-  if (ceData.widgetObjectTypes.contains(TQWIDGET_OBJECT_NAME_STRING)) {
+  if (ceData.widgetObjectTypes.contains("TQWidget")) {
     TQWidget *w = reinterpret_cast<TQWidget*>(ptr);
 
     bool tmpBool = false;
@@ -755,7 +755,7 @@ void LiquidStyle::polish( const TQStyleControlElementData &ceData, ControlElemen
 
 void LiquidStyle::unPolish( const TQStyleControlElementData &ceData, ControlElementFlags elementFlags, void *ptr ) {
 
-    if (ceData.widgetObjectTypes.contains(TQWIDGET_OBJECT_NAME_STRING)) {
+    if (ceData.widgetObjectTypes.contains("TQWidget")) {
         TQWidget *w = reinterpret_cast<TQWidget*>(ptr);
 
 	bool isViewport;
